@@ -17,6 +17,7 @@
 #include <libxml/entities.h>
 #include <libxml/parser.h>
 #include <libxml/xmlerror.h>
+#include <libxml/globals.h>
 
 /*
  * The XML predefined entities.
@@ -38,7 +39,7 @@ static struct xmlPredefinedEntityValue xmlPredefinedEntityValues[] = {
  * TODO: This is GROSS, allocation of a 256 entry hash for
  *       a fixed number of 4 elements !
  */
-xmlHashTablePtr xmlPredefinedEntities = NULL;
+static xmlHashTablePtr xmlPredefinedEntities = NULL;
 
 /*
  * xmlFreeEntity : clean-up an entity record.
