@@ -35,6 +35,7 @@
 #include <libxml/parser.h>
 #include <libxml/valid.h>
 #include <libxml/xlink.h>
+#include <libxml/globals.h>
 
 #define XLINK_NAMESPACE (BAD_CAST "http://www.w3.org/1999/xlink/namespace/")
 #define XHTML_NAMESPACE (BAD_CAST "http://www.w3.org/1999/xhtml/")
@@ -45,8 +46,8 @@
  *								*
  ****************************************************************/
  
-xlinkHandlerPtr xlinkDefaultHandler = NULL;
-xlinkNodeDetectFunc	xlinkDefaultDetect = NULL;
+static xlinkHandlerPtr xlinkDefaultHandler = NULL;
+static xlinkNodeDetectFunc	xlinkDefaultDetect = NULL;
 
 /**
  * xlinkGetDefaultHandler:
