@@ -136,7 +136,7 @@ xmlCleanupInputCallbacks(void)
     if (!xmlInputCallbackInitialized)
         return;
 
-    for (i = xmlInputCallbackNr - 1; i <= 0; i--) {
+    for (i = xmlInputCallbackNr - 1; i >= 0; i--) {
         xmlInputCallbackTable[i].matchcallback = NULL;
         xmlInputCallbackTable[i].opencallback = NULL;
         xmlInputCallbackTable[i].readcallback = NULL;
@@ -144,7 +144,6 @@ xmlCleanupInputCallbacks(void)
     }
 
     xmlInputCallbackNr = 0;
-    xmlInputCallbackInitialized = 0;
 }
 
 /**
@@ -161,7 +160,7 @@ xmlCleanupOutputCallbacks(void)
     if (!xmlOutputCallbackInitialized)
         return;
 
-    for (i = xmlOutputCallbackNr - 1; i <= 0; i--) {
+    for (i = xmlOutputCallbackNr - 1; i >= 0; i--) {
         xmlOutputCallbackTable[i].matchcallback = NULL;
         xmlOutputCallbackTable[i].opencallback = NULL;
         xmlOutputCallbackTable[i].writecallback = NULL;
@@ -169,7 +168,6 @@ xmlCleanupOutputCallbacks(void)
     }
 
     xmlOutputCallbackNr = 0;
-    xmlOutputCallbackInitialized = 0;
 }
 
 /************************************************************************
